@@ -4,6 +4,8 @@
 
 """python-mbedtls is a this wrapper to ARM's mbed TLS library."""
 
+# pylint: disable=consider-using-from-import
+
 from __future__ import annotations
 
 import mbedtls.cipher as cipher
@@ -17,12 +19,11 @@ import mbedtls.tls as tls
 import mbedtls.version as version
 import mbedtls.x509 as x509
 
-__version__ = "2.5.1"
+__version__ = "2.6.0"
 
 __all__ = (
     "cipher",
     "exceptions",
-    "hash",
     "hashlib",
     "hkdf",
     "hmac",
