@@ -2,10 +2,6 @@
 
 """Unit tests for mbedtls.cipher."""
 
-# Disable checks for violations that are acceptable in tests.
-# pylint: disable=missing-docstring
-# pylint: disable=attribute-defined-outside-init
-# pylint: disable=invalid-name, redefined-outer-name
 from __future__ import annotations
 
 import pickle
@@ -14,6 +10,7 @@ from collections import defaultdict
 from typing import (
     Any,
     Callable,
+    Iterable,
     Iterator,
     Mapping,
     NamedTuple,
@@ -26,6 +23,7 @@ from typing import (
 
 import pytest
 
+from mbedtls import has_feature
 from mbedtls.cipher import (
     AES,
     ARC4,
@@ -41,7 +39,6 @@ from mbedtls.cipher import (
     Mode,
     get_supported_ciphers,
 )
-from mbedtls.cipher._cipher import CIPHER_NAME  # type: ignore
 from mbedtls.exceptions import TLSError
 
 
@@ -57,12 +54,12 @@ def constant(value: T) -> Callable[[], T]:
     return lambda: value
 
 
-M = TypeVar("M", bound=Union[CipherType, AEADCipherType])
+_CipherModule = TypeVar(
+    "_CipherModule", bound=Union[CipherType, AEADCipherType]
+)
 
 
-SUPPORTED_SIZES: Mapping[
-    Union[CipherType, AEADCipherType], Mapping[Mode, Size]
-] = {
+SUPPORTED_SIZES: Mapping[object, Mapping[Mode, Size]] = {
     AES: defaultdict(
         constant(Size(key_size=(16, 24, 32), iv_size=16)),
         {
@@ -114,7 +111,7 @@ SUPPORTED_SIZES: Mapping[
 }
 
 
-SUPPORTED_MODES: Mapping[CipherType, Sequence[Mode]] = {
+SUPPORTED_MODES: Mapping[object, Sequence[Mode]] = {
     AES: (
         Mode.ECB,
         Mode.CBC,
@@ -139,20 +136,24 @@ SUPPORTED_MODES: Mapping[CipherType, Sequence[Mode]] = {
     DES3dbl: (Mode.ECB, Mode.CBC),
 }
 
-SUPPORTED_CIPHERS: Sequence[CipherType] = tuple(SUPPORTED_MODES.keys())
+SUPPORTED_CIPHERS: Sequence[object] = tuple(SUPPORTED_MODES.keys())
 
-SUPPORTED_AEAD_MODES: Mapping[AEADCipherType, Sequence[Mode]] = {
+SUPPORTED_AEAD_MODES: Mapping[object, Sequence[Mode]] = {
     AES: (Mode.GCM, Mode.CCM),
     CHACHA20: (Mode.CHACHAPOLY,),
 }
 
-SUPPORTED_AEAD_CIPHERS: Sequence[AEADCipherType] = tuple(SUPPORTED_AEAD_MODES)
+SUPPORTED_AEAD_CIPHERS: Sequence[object] = tuple(SUPPORTED_AEAD_MODES)
+
+
+def modname(mod: _CipherModule) -> str:
+    return mod.__name__.rsplit(".", 1)[-1]
 
 
 def gen_cipher_data(
-    module: M,
+    module: object,
     *,
-    modes: Mapping[M, Sequence[Mode]],
+    modes: Mapping[object, Sequence[Mode]],
 ) -> Iterator[Tuple[int, Mode, int]]:
     for mode in modes[module]:
         sizes = SUPPORTED_SIZES[module][mode]
@@ -161,16 +162,16 @@ def gen_cipher_data(
 
 
 def gen_cipher(
-    modules: Sequence[M],
+    modules: Iterable[object],
     *,
-    modes: Mapping[M, Sequence[Mode]],
-) -> Iterator[Tuple[M, int, Mode, int]]:
+    modes: Mapping[object, Sequence[Mode]],
+) -> Iterator[Tuple[object, int, Mode, int]]:
     for module in modules:
         for key_size, mode, iv_size in gen_cipher_data(module, modes=modes):
             yield module, key_size, mode, iv_size
 
 
-def paramids(params: Tuple[M, int, Mode, int]) -> str:
+def paramids(params: Tuple[_CipherModule, int, Mode, int]) -> str:
     module, key_size, mode, iv_size = params
     return (
         f"{module.__name__}, "
@@ -180,14 +181,11 @@ def paramids(params: Tuple[M, int, Mode, int]) -> str:
     )
 
 
-def test_cipher_list() -> None:
-    assert len(CIPHER_NAME) == 74
-
-
 def test_get_supported_ciphers() -> None:
-    cl = get_supported_ciphers()
-    assert cl
-    assert set(cl).issubset(set(CIPHER_NAME))
+    # Check a few basic ciphers that really have to be present.
+    assert b"AES-128-ECB" in get_supported_ciphers()
+    assert b"AES-192-ECB" in get_supported_ciphers()
+    assert b"AES-256-ECB" in get_supported_ciphers()
 
 
 class TestCipher:
@@ -196,7 +194,11 @@ class TestCipher:
         ids=paramids,
     )
     def params(self, request: Any) -> Tuple[CipherType, int, Mode, int]:
-        module = request.param[0]
+        module: CipherType = request.param[0]
+        name = modname(module)
+        if not has_feature({"DES3": "DES", "DES3dbl": "DES"}.get(name, name)):
+            return pytest.skip(f"{name} unavailable")
+        assert isinstance(ARIA, CipherType)
         if module is ARIA and sys.platform.startswith("win"):
             return pytest.skip("unsupported")
 
@@ -234,8 +236,6 @@ class TestCipher:
     ) -> None:
         module, key_size, mode, iv_size = params
         cipher = module.new(randbytes(key_size), mode, randbytes(iv_size))
-        assert cipher.name in CIPHER_NAME
-        assert CIPHER_NAME[cipher._type] == cipher.name
         assert str(cipher) == cipher.name.decode("ascii")
 
     def test_encrypt_decrypt(
@@ -279,9 +279,10 @@ class TestAEADCipher:
         ids=paramids,
     )
     def params(self, request: Any) -> Tuple[AEADCipherType, int, Mode, int]:
-        module = request.param[0]
-        if module is ARIA and sys.platform.startswith("win"):
-            return pytest.skip("unsupported")
+        module: AEADCipherType = request.param[0]
+        name = modname(module)
+        if not has_feature({"DES3": "DES", "DES3dbl": "DES"}.get(name, name)):
+            return pytest.skip(f"{name} unavailable")
 
         return cast(Tuple[AEADCipherType, int, Mode, int], request.param)
 
@@ -338,8 +339,6 @@ class TestAEADCipher:
             iv=randbytes(iv_size),
             ad=randbytes(ad_size),
         )
-        assert cipher.name in CIPHER_NAME
-        assert CIPHER_NAME[cipher._type] == cipher.name
         assert str(cipher) == cipher.name.decode("ascii")
 
     @pytest.mark.parametrize("ad_size", [0, 1, 16, 256])
@@ -400,7 +399,7 @@ class TestAEADCipher:
             if cipher.mode is Mode.ECB
             else cipher.block_size * 128
         )
-        msg, tag = cipher.encrypt(data)
+        _msg, tag = cipher.encrypt(data)
         with pytest.raises(TLSError):
             cipher.decrypt(b"", tag)
 
@@ -420,15 +419,20 @@ class TestGenericCipher:
         ]
     )
     def module(self, request: Any) -> CipherType:
-        if request.param is ARIA and sys.platform.startswith("win"):
-            return pytest.skip()
-        return cast(CipherType, request.param)
+        module: CipherType = request.param
+        name = modname(module)
+        if not has_feature({"DES3": "DES", "DES3dbl": "DES"}.get(name, name)):
+            return pytest.skip(f"{name} unavailable")
+        assert isinstance(ARIA, CipherType)
+        if module is ARIA and sys.platform.startswith("win"):
+            return pytest.skip("unsupported")
+        return module
 
     def test_unsupported_mode(
         self, module: CipherType, randbytes: Callable[[int], bytes]
     ) -> None:
         supported_modes = frozenset(SUPPORTED_MODES[module]) | frozenset(
-            SUPPORTED_AEAD_MODES.get(module, ())  # type: ignore[call-overload]
+            SUPPORTED_AEAD_MODES.get(module, ())
         )
         for key_size, mode, iv_size in gen_cipher_data(
             module,
@@ -444,9 +448,7 @@ class TestGenericCipher:
     ) -> None:
         mode = Mode.CBC
         if mode not in SUPPORTED_MODES[module]:
-            return pytest.skip(  # type: ignore[return-value]
-                f"unsupported mode for {module!r}: {mode!s}"
-            )
+            pytest.skip(f"unsupported mode for {module!r}: {mode!s}")
 
         sizes = SUPPORTED_SIZES[module][mode]
         for key_size in sizes.key_size:
